@@ -5,16 +5,16 @@ use warnings;
 use bytes;
 require Exporter ;
 
-use IO::Compress::Base 2.033 ;
+use IO::Compress::Base 2.034 ;
 
-use IO::Compress::Base::Common  2.033 qw(createSelfTiedObject);
+use IO::Compress::Base::Common  2.034 qw(createSelfTiedObject);
 use IO::Compress::Adapter::Lzma 2.006 ;
 
 
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $LzmaError);
 
-$VERSION = '2.033';
+$VERSION = '2.034';
 $LzmaError = '';
 
 @ISA    = qw(Exporter IO::Compress::Base);
@@ -51,7 +51,7 @@ sub getExtraParams
 {
     my $self = shift ;
 
-    use IO::Compress::Base::Common  2.033 qw(:Parse);
+    use IO::Compress::Base::Common  2.034 qw(:Parse);
     
     return (
         'Filter'     => [0, 1, Parse_any,   [] ],
@@ -681,7 +681,7 @@ If the C<$z> object is associated with a file or a filehandle, C<fileno>
 will return the underlying file descriptor. Once the C<close> method is
 called C<fileno> will return C<undef>.
 
-If the C<$z> object is is associated with a buffer, this method will return
+If the C<$z> object is associated with a buffer, this method will return
 C<undef>.
 
 =head2 close
